﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.Text.RegularExpressions;
namespace DHTMLX.Export.PDF.Scheduler
{
    public class SchedulerEvent
    {
        private int day = 0;
        private int week = 0;
        private int month = 0;
        private int len = 0;
        private double x = 0;
        private double y = 0;
        private double width;
        private double height;
        private string type;
        private string headerText;
        private string headerAgendaText;
        private string text = "";
        private string backgroundColor;
        private string color;
        private int footenote = -1;


        private string _GetNodeValue(XmlNode node)
        {
            var txt = node.FirstChild != null ? node.FirstChild.Value : "";
            if (string.IsNullOrEmpty(txt))
                txt = node.InnerText;

            if (txt == null)
                txt = "";
            return txt;
        }
        private int _GetNumAttributeValue(XmlNode node, string attr)
        {
            string val = node.Attributes[attr] != null ? node.Attributes[attr].Value : "0" ;
            int result = 0;
            if (!string.IsNullOrEmpty(val) && val != "undefined")
                int.TryParse(val, out result);
            return result;
        }
        private string _GetAttributeValue(XmlNode node, string attr)
        {
            return node.Attributes[attr] != null ? node.Attributes[attr].Value : "0";
            
        }
        private double _GetDoublAttributeValue(XmlNode node, string attr)
        {
            string val = node.Attributes[attr] != null ? node.Attributes[attr].Value : "0";
            double result = 0;
           
            if (!string.IsNullOrEmpty(val) && val != "undefined")
                double.TryParse(val, System.Globalization.NumberStyles.Any, System.Globalization.NumberFormatInfo.InvariantInfo, out result);
            return result;
        }
        public void Parse(XmlNode parent)
        {
            var children = parent.ChildNodes;
            bool bgProcessed = false;
            for (int i = 0; i < children.Count; i++)
            {
                switch (children[i].LocalName)
                {
                    case "body":
                    {
                        this.text = _GetNodeValue(children[i]);
                        this.backgroundColor = _GetAttributeValue(children[i], "backgroundColor");
                        this.color = _GetAttributeValue(children[i], "color");
                        bgProcessed = true;
                        break;
                    }
                    case "header":
                    {
                        this.headerText = _GetNodeValue(children[i]);
                        break;
                    }
                    case "head":
                    {
                        this.headerAgendaText = _GetNodeValue(children[i]);
                        break;
                    }
                }
            }
            if (!bgProcessed)
            {
                this.backgroundColor = _GetAttributeValue(parent, "backgroundColor");
                this.color = _GetAttributeValue(parent, "color");
            }
            
            this.day = _GetNumAttributeValue(parent, "day");
            this.week = _GetNumAttributeValue(parent, "week");
            this.len = _GetNumAttributeValue(parent, "len");
            this.month = _GetNumAttributeValue(parent, "month");


            this.x = _GetDoublAttributeValue(parent, "x");
            this.y = _GetDoublAttributeValue(parent, "y");
            this.width = _GetDoublAttributeValue(parent, "width");
            this.height = _GetDoublAttributeValue(parent, "height");
           

            this.type = _GetAttributeValue(parent, "type");

            
        }

        public string getText()
        {
            if (this.text == null)
                this.text = "";
            return this.text;
        }

        public int getDay()
        {
            return this.day;
        }

        public int getWeek()
        {
            return this.week;
        }

        public int getLen()
        {
            return this.len;
        }

        public int getMonth()
        {
            return this.month;
        }

        public double getX()
        {
            return this.x;
        }

        public double getY()
        {
            return this.y;
        }

        public string getType()
        {
            return this.type;
        }

        public double getWidth()
        {
            return this.width;
        }

        public double getHeight()
        {
            return this.height;
        }

        public string getBackgroundColor()
        {
            this.backgroundColor = this.processColor(this.backgroundColor);
            return this.backgroundColor;
        }

        public string getColor()
        {
            this.color = this.processColor(this.color);
            return this.color;
        }

        public string getHeaderText()
        {
            return this.headerText;
        }

        public string getHeaderAgendaText()
        {
            return this.headerAgendaText;
        }

        private string processColor(string color)
        {
           
            if (Regex.IsMatch(color, "#[0-9A-Fa-f]{6}"))
            {
                return color.Substring(1);
            }

            if (Regex.IsMatch(color, "[0-9A-Fa-f]{6}"))
            {
                return color;
            }

            var m3 = Regex.Match(color, "rgb\\s?\\(\\s?(\\d{1,3})\\s?,\\s?(\\d{1,3})\\s?,\\s?(\\d{1,3})\\s?\\)");

            if (m3.Length > 0)
            {
                color = "";
                String r = m3.Groups[1].Value;
                String g = m3.Groups[2].Value;
                String b = m3.Groups[3].Value;
                r = int.Parse(r).ToString("x");
                r = (r.Length == 1) ? "0" + r : r;
                g = int.Parse(g).ToString("x");
                g = (g.Length == 1) ? "0" + g : g;
                b = int.Parse(b).ToString("x");
                b = (b.Length == 1) ? "0" + b : b;
                color = r + g + b;
                return color;
            }
            return "transparent";
        }

        public void setFootenote(int footenote)
        {
            this.footenote = footenote;
        }

        public int getFootenote()
        {
            return this.footenote;
        }
    }
}
